function[Sist,U, iteration] = nbtp_lfnr(Sgsoll,Slsoll,Ustart,Y,REF,k,Convergence_value,iteration_max,PU,PQ)
%--------------------------------------------------------------------------------------
%                        Newton Raphson Power Flow calculation 
%
%  Input :         Sgsoll    		= generator power setpoint
%                  Slsoll    		= load power setpoint  
%                  Ustart     		= start value of the voltage 
%                  Y         		= nodal admittance matrix
%                  REF        		= Referencenode (just one node!)
%                  k         		= total number of nodes
%                  convergence_value= Value for convergecy
%                  iteration_max	= Max. interation number
%           
% Output :         Sist        = complexe nodal power 
%                  U           = complexe nodal voltage
%				   iteration  = number of interations
%--------------------------------------------------------------------------------------


% TASK 1: 
% Initialization
% ----------------------------------------------------------------------------

% nodal voltages magnitudes and phases
Ui = ?
di = ?

% complexe nodal powers
Ssoll = ?

% nodal admittance magnitudes and phases
y = ?
theta = ?
%-----------------------------------------------------------------------------






% TASK 2
% Iteration
% ----------------------------------------------------------------------------

for iteration = 1:iteration_max

	for in = 1:k     
		 P(in) = sum( Ui(in) .* Ui .* y(:,in) .* cos(di(in)-di-theta(:,in)) );
		 Q(in) = sum( Ui(in) .* Ui .* y(:,in) .* sin(di(in)-di-theta(:,in)) );
	end

	deltaPi = real(Ssoll) - P';          % deltaPi = real(Ssoll([PU;PQ]));
	deltaQi = imag(Ssoll) - Q';          % deltaQi = imag(Ssoll(PQ));

	deltaPi(REF) = [];
	deltaQi(REF) = [];    
		
	epsilon = norm([deltaPi;deltaQi], inf); 
		
    % Stop iteration in case of convergence
    ?
	
    % Jacobian Matrix 
	h=[];m=[];n=[];l=[];
	for in=1:k
		 ind_=[1:in-1 in+1:k];
		 
        h(in,:)= ?
        h(in,in)= ?
        
        m(in,:)= ?
        m(in,in)= ?
        
        n(in,:)= ?
        n(in,in)= ?
        
        l(in,:)= ?
        l(in,in)= ?
	end
	 
	J = [h, n; m, l];

	% Delete REF-node from Jakobian Matrix
	?

	res = J \ [deltaPi; deltaQi];
	 
	deltadi = res(1:k-1);
	deltaUi = res(k:2*k-2);
	 

	k_index = [ 1:REF-1 , REF+1:k ];
	Ui(k_index) = Ui(k_index) + deltaUi .* Ui(k_index);
	di(k_index) = di(k_index) + deltadi;
	 
  
end % End of iteration
% ----------------------------------------------------------------------------

U = Ui.*exp(j.*di);
if iteration == iteration_max 
	   disp('Maximum number of iterations is reached!!');
	   Sist = -1;
	   U = -1;
else  % iteration-1 because the convergence test is located after iteration variable is calculated with "+1"
	  disp(['The Power Flow calculation converged after ' num2str(iteration-1) ' iterations!']);
	  % Calculation of the powers
	  Sist = U.*(conj(Y)*conj(U));
end    
